#!/usr/bin/gnuplot

set colors classic

set xl "diameter, log {/Helvetica-Oblique D} / km"
set yl "number of asteroids, log {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [10.e-9:2000]
y1=0.5
y2=5.e26
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "{%T}"
set tics front
set bar 2.0
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.5 font "Helvetica,14"

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#00ccff' lw 2 pt 1		# evolved Massalia
set style line 7 lc rgb '#00ffcc' lw 2 pt 1		# evolved Massalia2
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set lmargin 7.5
set rmargin 2.1
set bmargin 3.2
set tmargin 2.2

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0

tmp=1.0e-6; set arrow from tmp,5.7e22 to tmp,2.9e19 size graph 0.02,30 empty lw 3 lc '#ccaaaa'
tmp=1.0e-4; set arrow from tmp,2.1e16 to tmp,1.0e14 size graph 0.02,30 empty lw 3 lc '#ccaaaa'
tmp=1.0e-2; set arrow from tmp,8.2e9  to tmp,3.5e8  size graph 0.02,30 empty lw 3 lc '#ccaaaa'

f_family0(x) = (1e13) * (x/0.001)**(-2.7)  # MB
f_family1(x) = (10**4.33037648e+00) * x**(-5.73545483e+00)  # Massalia
f_family2(x) = (10**3.40784296e+00) * x**(-2.80536346e+00)  # Massalia

#tmp=1.2; set label sprintf("    %.1f    ", -2.80536346e+00) at tmp,f_family2(tmp) font "Helvetica,14" right
#tmp=1.2; set label sprintf("    %.1f    ", -5.73545483e+00) at tmp,f_family2(tmp) font "Helvetica,14" left

set arrow from 1.0e-3,10e10 to 1.0e-3,30e10 heads lc 'black' front size graph 0.01,90 fixed

#set label "Ordovician craters"    at 1.0   ,graph 1.050 center font "Helvetica,14"
#set label "Eocene craters"        at 1.0   ,graph 1.023 center font "Helvetica,14"
#set label "fossil L-chondrites"   at 1.0e-3,graph 1.050 center font "Helvetica,14"
set label "observed L-chondrites" at 1.0e-3,graph 1.023 center font "Helvetica,14"
#set label "Ir excess"             at 1.0e-7,graph 1.050 center font "Helvetica,14"
set label "He-3 excess"           at 1.0e-7,graph 1.050 center font "Helvetica,14"
set label "dust band"             at 1.0e-7,graph 1.023 center font "Helvetica,14"

f_family3(x) = (9.0e21) * (x/100.e-9)**(-2.7)  # Massalia, extrapolation
f_family4(x) = (4.4e23) * (x/100.e-9)**(-2.7)  # MB, extrapolation
  
#set arrow from 100.e-9,f_family3(100e-9) to 10.e-9,f_family3(10e-9) nohead lt 0 lc 'black'
#set arrow from 100.e-9,f_family4(100e-9) to 10.e-9,f_family4(10e-9) nohead lt 0 lc 'black'

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/0040.000.out | ./hc.awk" u 1:2 w l ls 1 t "evolved MB",\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../*[0-9]*/tmp/0040.000.out | ./hc.awk" u 1:2 w l ls 2 t "evolved Massalia",\
  "<awk '(FNR==1){ print \"\"; } ($2==4)' ../*[0-9]*/tmp/0040.000.out | ./hc.awk" u 1:2 w l ls 7 t "evolved Massalia2",\
  "<./hc_sfd.awk ../src/sfd3.dat_EDITED" u 1:2 w l ls 4 t "initial Massalia",\
  "<./hc_sfd.awk ../src/sfd4.dat_EDITED" u 1:2 w l ls 4 t "initial Massalia2",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\
  "../src/20_Massalia_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Massalia",\
  "<echo  30.e-9  3.6e25 1.8e25" u 1:2:3 w err pt 1 ps 0 lw 5 lc '#0066ff' t "zodiacal cloud",\
  "<echo  30.e-9  1.6e24 1.1e24" u 1:2:3 w err pt 1 ps 0 lw 5 lc '#00ffcc' t "IRAS 1.4{/Symbol\260} band",\

pa -1

set term postscript eps enh color solid "Helvetica" 18
set out "sfd_0040_RV4.eps"
set size 0.625*1.5,0.925*1.5
rep

system("eps2png sfd_0040_RV4.eps")

q

  "<echo  30.e-9  5.4e24 2.7e24" u 1:2:3 w err pt 1 ps 0 lw 5 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\
  "<echo  30.e-9 11.0e24 7.7e24" u 1:2:3 w err pt 1 ps 0 lw 5 lc '#0000cc' t "IRAS 9.3{/Symbol\260} band",\

  "<echo 100.e-9 9.7e24" w p pt 1 ps 3 lw 8 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9 4.0e23" w p pt 1 ps 3 lw 8 lc '#00ffcc' t "IRAS 1.4{/Symbol\260} band",\

  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\

  f_family0(x) not lc 'gray'    dt 2,\
  f_family1(x) not lc 'gray'    dt 2,\
  f_family2(x) not lc '#00ffff' dt 2,\


x1=0.2
x2=5
y1=1.e5
y2=1.e7

  "box.dat" u (x1+$1*(x2-x1)):(y1+$2*(y2-y1)) not w l lt 0,\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../*[0-9]*/tmp/0040.out | ./hc.awk" u 1:2 t "evolved NEA"    w l ls 3,\
  "../dat/Harris_etal_2015.dat"  u (10.**$1):(10.**$2) not w p lc rgb '#ffffff' pt 7 ps 1.0,\
  "../dat/Harris_etal_2015.dat"  u (10.**$1):(10.**$2) t "{/=14 Harris etal. (2015)}" w p ls 6,\

tmp=1; set arrow from tmp,graph 0 to tmp,graph 1 nohead lt 0
tmp=1.e6; set arrow from graph 0,first tmp to graph 1,first tmp nohead lt 0

set label "{/Helvetica-Bold=24 MB}" at 50,1e5 center tc rgb '#aaaaff'
set label "{/Helvetica-Bold=24 NEA}" at 0.1,500 center tc rgb '#888888'

#  "../src/MB_2018.dat_hc" u 1:2 t "observed MB" w l ls 5 lw 2,\
#  "../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2) t "Gladman etal. (2009)" w l ls 5 dt 2,\
#  "../dat/Cibulkova_etal_2014_MB.dat_hc" u 1:2 t "Cibulkova etal. (2014)" w l ls 5,\
#  "<./hc_sfd.awk sfd3.dat_EDITED" u 1:2 t "initial NEA"    w l  ls 4,\
#  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../[0-9]*/tmp/4000.out | ./hc.awk" u 1:2 t "evolved family" w lp ls 2,\



